// AnalyticsChart.js
import React from 'react';
import { Line } from 'react-chartjs-2';
import {
  Chart as ChartJS,
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  Title,
  Tooltip,
  Legend,
  TimeScale,
  TimeSeriesScale,
} from 'chart.js';
import 'chartjs-adapter-date-fns';


ChartJS.register(
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  Title,
  Tooltip,
  Legend,
  TimeScale,
  TimeSeriesScale
);

const AnalyticsChart = ({ analyticsData, label, dataKey }) => {
  const data = {
    labels: analyticsData.map((data) => data.created_at),
    datasets: [
      {
        label: label,
        data: analyticsData.map((data) => data[dataKey]),
        fill: false,
        borderColor: 'rgb(75, 192, 192)',
        tension: 0.1,
      },
    ],
  };

  const options = {
    scales: {
      x: {
        type: 'time',
        time: {
          parser: "yyyy-MM-dd'T'HH:mm:ss.SSSSSSxxx", // Adjusted date format parser for Date-fns
          unit: 'day',
          tooltipFormat: 'yyyy-MM-dd HH:mm',
        },
        title: {
          display: true,
          text: 'Date',
        },
      },
      y: {
        beginAtZero: true,
        title: {
          display: true,
          text: label,
        },
      },
    },
  };

  // Log the analyticsData to the console right here
  console.log("Logging analyticsData:", analyticsData);
  return <div className="chart-container">
    <Line data={data} options={options} />
  </div>;
};

export default AnalyticsChart;
