import React, { useEffect, useState } from 'react';
import './App.css';
import AnalyticsChart from './AnalyticsChart'; // Adjust the path as necessary

function App() {
  const [posts, setPosts] = useState([]);
  const [currentIndex, setCurrentIndex] = useState(0);
  const [analyticsData, setAnalyticsData] = useState(null); // New state for analytics data

  useEffect(() => {
    fetch('http://localhost:8000/api/posts/')
      .then(response => response.json())
      .then(data => setPosts(data))
      .catch(error => console.error('Error:', error));
  }, []);

  useEffect(() => {
    // Assuming each post has a unique ID, fetch analytics data for the current post
    const postId = posts[currentIndex]?.id; // Safe navigation operator to avoid undefined errors
    if (postId) {
      fetch(`http://localhost:8000/api/post_analytics/?post=${postId}`)
        .then(response => response.json())
        .then(data => setAnalyticsData(data))
        .catch(error => console.error('Error:', error));
    }
  }, [currentIndex, posts]); // Fetch analytics data when currentIndex or posts array changes

  const goToNextPost = () => setCurrentIndex(prevIndex => (prevIndex + 1) % posts.length);
  const goToPrevPost = () => setCurrentIndex(prevIndex => (prevIndex - 1 + posts.length) % posts.length);

  return (
    <div>
      <h1>Data from Django</h1>
      {posts.length > 0 ? (
        <div>
          <div key={posts[currentIndex].id}>
            <h2>{posts[currentIndex].title}</h2>
            <img src={posts[currentIndex].url} alt={posts[currentIndex].title} className="post-image" />
            <p>Posted on: {new Date(posts[currentIndex].created_utc * 1000).toLocaleDateString()}</p>
            <a href={`https://old.reddit.com${posts[currentIndex].permalink}`}>View on Reddit</a>
          </div>
          {analyticsData && (
            <>
              <AnalyticsChart analyticsData={analyticsData} label="Score Over Time" dataKey="score" />
              <AnalyticsChart analyticsData={analyticsData} label="Number of Comments Over Time" dataKey="num_comments" />
            </>
          )}
          <button onClick={goToPrevPost}>Prev</button>
          <button onClick={goToNextPost}>Next</button>
        </div>
      ) : (
        <p>Loading...</p>
      )}
    </div>
  );
}

export default App;
